[![License: Apache 2](https://img.shields.io/badge/License-apache2-green.svg)](LICENSE)
[![clipped](https://github.com/mmourafiq/clipped/actions/workflows/clipped.yml/badge.svg)](https://github.com/mmourafiq/clipped/actions/workflows/clipped.yml)

<a href="https://github.com/mmourafiq/clipped"><img src="https://raw.githubusercontent.com/mmourafiq/clipped/master/artifacts/logo/clipped.svg" width="125" height="125" align="right" /></a>

# Clipped

Common shortcuts and utils for Python and CLI projects.

## Install

```bash
pip install clipped
```
